@@ -24,6 +24,7 @@ sub rollout {
     my $log = $ssh->capture("mkdir -p " . $self->config->{deploy_dir});
     $self->log($ssh, $log);
     $self->checkout($ssh);
+    $self->post_rollout($ssh);
 
     return;
 }
@@ -35,11 +36,12 @@ sub rollout_timestamped {
     my $deploy_dir = join('/', $self->config->{root}, 'releases', time);
     my $current = join('/', $self->config->{root}, 'current');
     my $log = $ssh->capture("mkdir -p " . $deploy_dir);
+    $self->config->{deploy_dir} = $deploy_dir;
+    $self->checkout($ssh);
     $log .= $ssh->capture(
         "unlink " . $current . "; ln -s " . $deploy_dir . " " . $current);
-    $self->config->{deploy_dir} = $deploy_dir;
     $self->log($ssh, $log);
-    $self->checkout($ssh);
+    $self->post_rollout($ssh);
 
     return;
 }
@@ -71,7 +73,7 @@ sub rollback_timestamped {
             push(@past, $rel);
         }
     }
-    $deploy_dir = join('/', $self->config->{root}, pop(@past));
+    $deploy_dir = join('/', $self->config->{root}, 'releases', pop(@past));
     my $log = $ssh->capture(
         "unlink " . $current . "; ln -s " . $deploy_dir . " " . $current);
     $self->log($ssh, $log);
@@ -96,12 +98,8 @@ sub restart {
     my ($self, $ssh) = @_;
 
     $self->log("running restart task ...");
-    my ($pty, $pid) =
-        $ssh->open2pty("sudo " . $self->config->{init} . " restart");
-    my $exp = Expect->init($pty);
-    my $ret = $exp->interact();
-    $self->log($ssh, "restarted ..." . Dumper($exp));
-
+    my $log = $ssh->capture($self->config->{init});
+    $self->log($ssh, $log);
     return;
 }
 
@@ -160,13 +158,16 @@ sub cleanup_timestamped {
 }
 
 sub restart_phased {
-    my ($self, $ssh, $conf) = @_;
+    my ($self, $ssh) = @_;
 
     $self->log($ssh, "running restart_phased task ...");
     unless ($ssh->test("sudo " . $self->config->{init} . " restart")) {
         $self->log(
             'restart failed: ' . $ssh->error . ' trying stop -> start instead');
         $ssh->test("sudo " . $self->config->{init} . " stop");
+
+        # give time to exit
+        sleep 2;
         $ssh->test("sudo " . $self->config->{init} . " start")
             or $self->error('restart failed: ' . $ssh->error);
         return;
@@ -179,11 +180,82 @@ sub restart_phased {
     return;
 }
 
+sub reload_phased {
+    my ($self, $ssh) = @_;
+
+    $self->log($ssh, "running reload_phased task ...");
+    unless ($ssh->test("sudo " . $self->config->{reload})) {
+        $self->log(
+            'reload failed: ' . $ssh->error . ' trying stop -> start instead');
+        $ssh->test("sudo " . $self->config->{init} . " stop");
+
+        # give time to exit
+        sleep 2;
+        $ssh->test("sudo " . $self->config->{init} . " start")
+            or $self->error('restart failed: ' . $ssh->error);
+        return;
+    }
+
+    # my $exp = Expect->init($pty);
+    # $exp->interact();
+    $self->log($ssh, 'reloaded ' . $self->config->{reload});
+
+    return;
+}
+
 sub send_notify {
     my ($self, $ssh) = @_;
     $self->log($ssh, "running send_notify task ...");
     return;
 }
 
+sub post_rollout {
+    my ($self, $ssh) = @_;
+
+    return
+        unless (exists $self->config->{post_rollout}
+        and defined $self->config->{post_rollout});
+
+    $self->log($ssh,
+              'running post_rollout script "'
+            . $self->config->{post_rollout}
+            . '" ...');
+    unless (
+        $ssh->test(
+                  'cd '
+                . $self->config->{deploy_dir} . ' && '
+                . $self->config->{post_rollout}))
+    {
+        $self->error("post_rollout script failed: " . $ssh->error);
+    }
+    return;
+}
 
 __PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Giovanni::Stages
+
+=head1 VERSION
+
+version 1.10
+
+=head1 AUTHOR
+
+Lenz Gschwendtner <mail@norbu09.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by ideegeo Group Limited.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
